==> py-coinspot-api-0.1.0.tar.gz: py-coinspot-api-0.1.0/setup.py <==
from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='py-coinspot-api',

    # Versions should comply with PEP440. For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version
    version='0.1.0',

    description='A python library for the Coinspot API',
    long_description='py-coinspot-api is a library to interface with the Coinspot cryptocurrency trading API.',

    # The project's main homepage.
    url='https://github.com/geekpete/py-coinspot-api',

    # Author details
    author='Peter Dyson',
    author_email='pete@geekpete.com',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        # 3 - Alpha
        # 4 - Beta
        # 5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='coinspot api development bitcoin dogecoin litecoin cryptocurrency',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
)

==> py-coinspot-api-0.2.2.tar.gz: py-coinspot-api-0.2.2/setup.py <==
from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

here = path.abspath(path.dirname(__file__))


def readme():
    with open('README.rst') as f:
        return f.read()

setup(
    name='py-coinspot-api',

    # Versions should comply with PEP440. For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version
    version='0.2.2',

    description='A python library for the Coinspot API',
    long_description=readme(),

    # The project's main homepage.
    url='https://github.com/geekpete/py-coinspot-api',

    # Author details
    author='Peter Dyson',
    author_email='pete@geekpete.com',

    # Choose your license
    license='GPLv3',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        # 3 - Alpha
        # 4 - Beta
        # 5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='coinspot api development bitcoin dogecoin litecoin cryptocurrency',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
)
